# wpilib.kinematics

This is a pure-Python port of the WPILib 2020 kinematics classes for RobotPy 2019.

Note: This is provided on a best-effort basis. Things may move or become unavailable in RobotPy WPILib 2020.

## Warning
It is anticipated that RobotPy WPILib 2020 will eventually wrap the geometry and kinematics classes,
most likely in an update that will bump the wpilib package to 2020.2.2.
When this happens, you *must* uninstall this package before updating your RobotPy installation.

## Installation
`pip install wpilib.kinematics`
